TCT.translator_node — Translator Component Toolkit 0.1 documentation

# TCT.translator_node

class TCT.translator_node.TranslatorEdge(subject: str, object: str, predicate: str)

  Class that represents Translator edges.

  object: str

    Predicates

  subject: str

    The object is a CURIE id for a node.

class TCT.translator_node.TranslatorNode(curie: str, label: str | None = None, types: list[str] | None = None, synonyms: list[str] | None = None, curie_synonyms: list[str] | None = None)

  Class for Translator graph nodes.

  Attributes:
    curie_synonyms
    `identifier`

      identifier is the CURIE id for the node.

    label
    synonyms
    types
  curie: str

    name

  property identifier

    identifier is the CURIE id for the node.

  label: str | None = None

    list of biolink types

  synonyms: list[str] | None = None

    list of synonymous CURIE ids (in the same order as synonyms)

  types: list[str] | None = None

    list of synonymous labels